@@ -10,6 +10,8 @@
 
 /* This too was (obviously) not written for performance. */
 
+
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -18,7 +20,8 @@
 #include "vobinfo.h"
 
 char vobFilename[MAX_NAME_LENGTHS] = "vts_01_1.vob"; 
-char traceFilename[MAX_NAME_LENGTHS] = "vobtrace";  
+char traceFilename[MAX_NAME_LENGTHS];  
+char *defaultTraceFilename = "vobtrace";
 char rootName[MAX_NAME_LENGTHS] = ""; 
 char demuxPath[MAX_NAME_LENGTHS] = "./"; 
 int traceFlag = 0;
@@ -26,7 +29,7 @@ int tracePayload = 0;
 int traceErrors = 0;
 int commentaryFlag = 1;
 int summaryFlag = 1;
-int demuxAllFlag = 1;
+int demuxAllFlag = 0;
 int demuxOneId = 0;
 char demuxOneFilename[MAX_NAME_LENGTHS] = "-";
 
@@ -284,7 +287,7 @@ static void DoPacketData(int stream_id,int numBytesThisPacket,BitFile *bitFilePt
       strcpy(demuxFilename,demuxPath);
       strcat(demuxFilename,rootName);
       strcat(demuxFilename,stream_id_consts[stream_id-0xbc].extension);
-      stream_id_stats[stream_id-0xbc].filePtr = fopen(demuxFilename,"wb");
+      stream_id_stats[stream_id-0xbc].filePtr = fopen(demuxFilename,"wb");/*open a demux file for the newly discovered stream */
       if(stream_id_stats[stream_id-0xbc].filePtr == NULL) {
          fprintf(stderr,"ERROR: could not open \"%s\"\n",demuxFilename); 
          exit(-7);
@@ -312,152 +315,152 @@ static void ParsePesPacket(BitFile *bitFilePtr)
    char stream_id_comment[128],*dataCommentPtr;
 
    numPesPacketsFound++;
-   BitFileReadBits(bitFilePtr,24,"packet_start_code_prefix"); /* should be 0x000001 */
+   BitFileReadBits(bitFilePtr,24," packet_start_code_prefix"); /* should be 0x000001 */
    stream_id = BitFilePeekBits(bitFilePtr,8,NULL); 
-   strcpy(stream_id_comment,"stream_id = ");
+   strcpy(stream_id_comment," stream_id = ");
    strcpy(stream_id_comment+12,stream_id_consts[stream_id-0xbc].namePtr);
    BitFileReadBits(bitFilePtr,8,stream_id_comment); 
-   PES_packet_length = BitFileReadBits(bitFilePtr,16,"PES_packet_length"); 
+   PES_packet_length = BitFileReadBits(bitFilePtr,16," PES_packet_length"); 
    pesPacketDataStartFTell = BitFileFTell(bitFilePtr);
    if(stream_id_consts[stream_id-0xbc].parseChoice == 0) {
       int PTS_DTS_flags, ESCR_flag, ES_rate_flag, DSM_trick_mode_flag, additional_copy_info_flag;
       int PES_CRC_flag, PES_extension_flag, PES_header_data_length;
-      BitFileReadBits(bitFilePtr,2,"'10'"); 
+      BitFileReadBits(bitFilePtr,2," '10'"); 
       if(BitFilePeekBits(bitFilePtr,2,NULL) == 0) 
-         BitFileReadBits(bitFilePtr,2,"PES_scrambling_control = not scrambled"); 
+         BitFileReadBits(bitFilePtr,2," PES_scrambling_control = not scrambled"); 
       else
-         BitFileReadBits(bitFilePtr,2,"PES_scrambling_control = user defined"); 
-      BitFileReadBits(bitFilePtr,1,"PES_priority"); 
-      BitFileReadBits(bitFilePtr,1,"data_alignment_indicator"); 
+         BitFileReadBits(bitFilePtr,2," PES_scrambling_control = user defined"); 
+      BitFileReadBits(bitFilePtr,1," PES_priority"); 
+      BitFileReadBits(bitFilePtr,1," data_alignment_indicator"); 
       if(BitFilePeekBits(bitFilePtr,1,NULL))
-         BitFileReadBits(bitFilePtr,1,"Copyright = yes"); 
+         BitFileReadBits(bitFilePtr,1," Copyright = yes"); 
       else
-         BitFileReadBits(bitFilePtr,1,"Copyright = status not specified"); 
+         BitFileReadBits(bitFilePtr,1," Copyright = status not specified"); 
       if(BitFilePeekBits(bitFilePtr,1,NULL))
-         BitFileReadBits(bitFilePtr,1,"original_or_copy = original"); 
+         BitFileReadBits(bitFilePtr,1," original_or_copy = original"); 
       else
-         BitFileReadBits(bitFilePtr,1,"original_or_copy = copy"); 
-      PTS_DTS_flags =             BitFileReadBits(bitFilePtr,2,"PTS_DTS_flags"); 
-      ESCR_flag =                 BitFileReadBits(bitFilePtr,1,"ESCR_flag"); 
-      ES_rate_flag =              BitFileReadBits(bitFilePtr,1,"ES_rate_flag"); 
-      DSM_trick_mode_flag =       BitFileReadBits(bitFilePtr,1,"DSM_trick_mode_flag"); 
-      additional_copy_info_flag = BitFileReadBits(bitFilePtr,1,"additional_copy_info_flag"); 
-      PES_CRC_flag =              BitFileReadBits(bitFilePtr,1,"PES_CRC_flag"); 
-      PES_extension_flag =        BitFileReadBits(bitFilePtr,1,"PES_extension_flag"); 
-      PES_header_data_length =    BitFileReadBits(bitFilePtr,8,"PES_header_data_length"); 
+         BitFileReadBits(bitFilePtr,1," original_or_copy = copy"); 
+      PTS_DTS_flags =             BitFileReadBits(bitFilePtr,2," PTS_DTS_flags"); 
+      ESCR_flag =                 BitFileReadBits(bitFilePtr,1," ESCR_flag"); 
+      ES_rate_flag =              BitFileReadBits(bitFilePtr,1," ES_rate_flag"); 
+      DSM_trick_mode_flag =       BitFileReadBits(bitFilePtr,1," DSM_trick_mode_flag"); 
+      additional_copy_info_flag = BitFileReadBits(bitFilePtr,1," additional_copy_info_flag"); 
+      PES_CRC_flag =              BitFileReadBits(bitFilePtr,1," PES_CRC_flag"); 
+      PES_extension_flag =        BitFileReadBits(bitFilePtr,1," PES_extension_flag"); 
+      PES_header_data_length =    BitFileReadBits(bitFilePtr,8," PES_header_data_length"); 
       if((PTS_DTS_flags&2)) {
-         BitFileReadBits(bitFilePtr,4,"'0010'"); 
-         BitFileReadBits(bitFilePtr,3,"PTS [32..30]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"PTS [29..15]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"PTS [14..0]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,4," '0010'"); 
+         BitFileReadBits(bitFilePtr,3," PTS [32..30]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," PTS [29..15]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," PTS [14..0]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
       };
       if((PTS_DTS_flags&2)) {
-         BitFileReadBits(bitFilePtr,4,"'0001'"); 
-         BitFileReadBits(bitFilePtr,3,"DTS [32..30]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"DTS [29..15]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"DTS [14..0]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,4," '0001'"); 
+         BitFileReadBits(bitFilePtr,3," DTS [32..30]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," DTS [29..15]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," DTS [14..0]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
       };
       if(ESCR_flag) {
-         BitFileReadBits(bitFilePtr,2,"reserved"); 
-         BitFileReadBits(bitFilePtr,3,"ESCR [32..30]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"ESCR [29..15]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,15,"ESCR [14..0]"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,9,"ESCR_extension"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,2," reserved"); 
+         BitFileReadBits(bitFilePtr,3," ESCR [32..30]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," ESCR [29..15]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,15," ESCR [14..0]"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,9," ESCR_extension"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
       };
       if(ES_rate_flag) {
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,22,"ES_rate"); 
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,22," ES_rate"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
       };
       if(DSM_trick_mode_flag) {
          int trick_mode_control;
-         trick_mode_control = BitFilePeekBits(bitFilePtr,3,"trick_mode_control"); 
+         trick_mode_control = BitFilePeekBits(bitFilePtr,3," trick_mode_control"); 
          if(trick_mode_control ==  0) {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = fast forward"); 
-            BitFileReadBits(bitFilePtr,2,"field_id"); 
-            BitFileReadBits(bitFilePtr,1,"intra_slice_refresh"); 
-            BitFileReadBits(bitFilePtr,2,"frequency_truncation"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = fast forward"); 
+            BitFileReadBits(bitFilePtr,2," field_id"); 
+            BitFileReadBits(bitFilePtr,1," intra_slice_refresh"); 
+            BitFileReadBits(bitFilePtr,2," frequency_truncation"); 
          } else if(trick_mode_control ==  1) {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = slow motion"); 
-            BitFileReadBits(bitFilePtr,5,"rep_ctrl"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = slow motion"); 
+            BitFileReadBits(bitFilePtr,5," rep_ctrl"); 
          } else if(trick_mode_control ==  2) {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = freeze frame"); 
-            BitFileReadBits(bitFilePtr,2,"field_id"); 
-            BitFileReadBits(bitFilePtr,3,"reserved"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = freeze frame"); 
+            BitFileReadBits(bitFilePtr,2," field_id"); 
+            BitFileReadBits(bitFilePtr,3," reserved"); 
          } else if(trick_mode_control ==  3) {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = fast reverse"); 
-            BitFileReadBits(bitFilePtr,2,"field_id"); 
-            BitFileReadBits(bitFilePtr,1,"intra_slice_refresh"); 
-            BitFileReadBits(bitFilePtr,2,"frequency_truncation"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = fast reverse"); 
+            BitFileReadBits(bitFilePtr,2," field_id"); 
+            BitFileReadBits(bitFilePtr,1," intra_slice_refresh"); 
+            BitFileReadBits(bitFilePtr,2," frequency_truncation"); 
          } else if(trick_mode_control ==  4) {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = slow reverse"); 
-            BitFileReadBits(bitFilePtr,5,"rep_ctrl"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = slow reverse"); 
+            BitFileReadBits(bitFilePtr,5," rep_ctrl"); 
          } else {
-            trick_mode_control = BitFileReadBits(bitFilePtr,3,"trick_mode_control = reserved"); 
-            BitFileReadBits(bitFilePtr,5,"reserved"); 
+            trick_mode_control = BitFileReadBits(bitFilePtr,3," trick_mode_control = reserved"); 
+            BitFileReadBits(bitFilePtr,5," reserved"); 
          };
       };
       if(additional_copy_info_flag) {
-         BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-         BitFileReadBits(bitFilePtr,7,"additional_copy_info"); 
+         BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+         BitFileReadBits(bitFilePtr,7," additional_copy_info"); 
       };
       if(PES_CRC_flag) {
-         BitFileReadBits(bitFilePtr,16,"previous_PES_packet_CRC"); 
+         BitFileReadBits(bitFilePtr,16," previous_PES_packet_CRC"); 
       };
       if(PES_extension_flag) {
          int PES_private_data_flag, pack_header_field_flag, program_packet_sequence_counter_flag;
          int P_STD_buffer_flag, PES_extension_flag_2,privateDataToGo;
-         PES_private_data_flag = BitFileReadBits(bitFilePtr,1,"PES_private_data_flag"); 
-         pack_header_field_flag = BitFileReadBits(bitFilePtr,1,"pack_header_field_flag"); 
-         program_packet_sequence_counter_flag = BitFileReadBits(bitFilePtr,1,"program_packet_sequence_counter_flag"); 
-         P_STD_buffer_flag = BitFileReadBits(bitFilePtr,1,"P-STD_buffer_flag"); 
-         BitFileReadBits(bitFilePtr,3,"reserved"); 
-         PES_extension_flag_2 = BitFileReadBits(bitFilePtr,1,"PES_extension_flag_2"); 
+         PES_private_data_flag = BitFileReadBits(bitFilePtr,1," PES_private_data_flag"); 
+         pack_header_field_flag = BitFileReadBits(bitFilePtr,1," pack_header_field_flag"); 
+         program_packet_sequence_counter_flag = BitFileReadBits(bitFilePtr,1," program_packet_sequence_counter_flag"); 
+         P_STD_buffer_flag = BitFileReadBits(bitFilePtr,1," P-STD_buffer_flag"); 
+         BitFileReadBits(bitFilePtr,3," reserved"); 
+         PES_extension_flag_2 = BitFileReadBits(bitFilePtr,1," PES_extension_flag_2"); 
          if(PES_private_data_flag) {
             for(privateDataToGo = 128/4;privateDataToGo;privateDataToGo--) 
-               BitFileReadBits(bitFilePtr,32,"PES_private_data"); 
+               BitFileReadBits(bitFilePtr,32," PES_private_data"); 
          };
          if(pack_header_field_flag) {
-            BitFileReadBits(bitFilePtr,8,"pack_field_length"); 
+            BitFileReadBits(bitFilePtr,8," pack_field_length"); 
             ParsePackHeader(bitFilePtr);
          };
          if(program_packet_sequence_counter_flag) {
-            BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-            BitFileReadBits(bitFilePtr,7,"program_packet_sequence_counter"); 
-            BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-            BitFileReadBits(bitFilePtr,1,"MPEG1_MPEG2_identifier"); 
-            BitFileReadBits(bitFilePtr,6,"original_stuff_length"); 
+            BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+            BitFileReadBits(bitFilePtr,7," program_packet_sequence_counter"); 
+            BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+            BitFileReadBits(bitFilePtr,1," MPEG1_MPEG2_identifier"); 
+            BitFileReadBits(bitFilePtr,6," original_stuff_length"); 
          };
          if(P_STD_buffer_flag) {
-            BitFileReadBits(bitFilePtr,2,"'01'"); 
-            BitFileReadBits(bitFilePtr,1,"P-STD_buffer_scale"); 
-            BitFileReadBits(bitFilePtr,13,"P-STD_buffer_size"); 
+            BitFileReadBits(bitFilePtr,2," '01'"); 
+            BitFileReadBits(bitFilePtr,1," P-STD_buffer_scale"); 
+            BitFileReadBits(bitFilePtr,13," P-STD_buffer_size"); 
          };
          if(PES_extension_flag_2) {
             int PES_extension_field_length;
-            BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
-            PES_extension_field_length = BitFileReadBits(bitFilePtr,7,"PES_extension_field_length"); 
+            BitFileReadBits(bitFilePtr,1," marker_bit (should be 1)"); 
+            PES_extension_field_length = BitFileReadBits(bitFilePtr,7," PES_extension_field_length"); 
             for(;PES_extension_field_length;PES_extension_field_length--) 
-               BitFileReadBits(bitFilePtr,8,"reserved"); 
+               BitFileReadBits(bitFilePtr,8," reserved"); 
          };
       };
       while(BitFilePeekBits(bitFilePtr,8,NULL) == 0xff) 
-         BitFileReadBits(bitFilePtr,8,"stuffing_byte"); 
-      dataCommentPtr = "PES_packet_data_byte";
+         BitFileReadBits(bitFilePtr,8," stuffing_byte"); 
+      dataCommentPtr = "  PES_packet_data_byte";
    } else if(stream_id_consts[stream_id-0xbc].parseChoice == 1) {
-      dataCommentPtr = "PES_packet_data_byte";
+      dataCommentPtr = "  PES_packet_data_byte";
    } else {  /* padding_stream */
-      dataCommentPtr = "padding_byte (should be 0xff)";
+      dataCommentPtr = "  padding_byte (should be 0xff)";
    };
    numDataBytes = PES_packet_length-(BitFileFTell(bitFilePtr)-pesPacketDataStartFTell)/8;
    DoPacketData(stream_id,numDataBytes,bitFilePtr,dataCommentPtr);
@@ -488,7 +491,7 @@ static void ParseVob(BitFile *bitFilePtr)
    };
    for(;;) {  /* for every PES (p-something elementary stream) packet */
       if((BitFileFTell(bitFilePtr)&7) != 0)
-         BitFileReadBits(bitFilePtr,8 - (BitFileFTell(bitFilePtr)&7),"fractional byte resync skip");
+         BitFileReadBits(bitFilePtr,8 - (BitFileFTell(bitFilePtr)&7)," fractional byte resync skip");
       for(;;) {  /* for every byte until we find a start code */
          if(BitFilePeekBits(bitFilePtr,32,NULL) == 0x000001ba)  /* pack_start_code */
             break;
@@ -514,10 +517,10 @@ static void ParseVob(BitFile *bitFilePtr)
       };
       bitPositionOfVobStart = BitFileFTell(bitFilePtr);
       ParsePack(bitFilePtr);
-      if(((BitFileFTell(bitFilePtr) - bitPositionOfVobStart)&0x1f))
-         BitFileReadBits(bitFilePtr,32-((BitFileFTell(bitFilePtr) - bitPositionOfVobStart)&0x1f),"skip VOB data");
+      if(((BitFileFTell(bitFilePtr) - bitPositionOfVobStart)&0x1f))  /* if we need to skip a fractional 32-bit dword */
+         BitFileReadBits(bitFilePtr,32-((BitFileFTell(bitFilePtr) - bitPositionOfVobStart)&0x1f),"  skip VOB data");
       while(BitFileFTell(bitFilePtr) - bitPositionOfVobStart < 2048*8)
-         BitFileReadBits(bitFilePtr,32,"skip VOB data");
+         BitFileReadBits(bitFilePtr,32,"  skip VOB data");  /* skip a 32-bit dword */
    };
 }
 
@@ -599,19 +602,19 @@ static void PrintHelpStreamId(void)
 static void PrintHelp(void)
 {
    printf("usage: vobinfo [options ..]\n"); 
-   printf("   --bittrace or --bittrace=filename (default is vts_01_1.vob)\n"); 
-   printf("   --vob=filename (current is \"%s\")\n",vobFilename); 
-   printf("   --notracepayload\n"); 
-   printf("   --notraceerrors\n"); 
+   printf("   --bittrace or --bittrace=filename (default is %s)\n",defaultTraceFilename); 
+   printf("   --vob=filename (default is vts_01_1.vob)\n"); 
+   printf("   --tracepayload\n"); 
+   printf("   --traceerrors\n"); 
    printf("   --help-stream_id\n"); 
    printf("   --nocommentary\n"); 
    printf("   --nosummary\n"); 
    printf("   --demuxall\n"); 
-   printf("   --demuxpath=path (default is ./)\n"); 
-   printf("   --demuxid=number (default is no demuliplex)\n"); 
-   printf("   --demuxfilename=filename (default is -)\n"); 
+   printf("   --demuxpath=path (for --demuxall, default is ./)\n"); 
+   printf("   --demuxid=stream_id_number (default is no demuliplex)\n"); 
+   printf("   --demuxfilename=filename (for --demuxid, default is - (stdout))\n"); 
    printf("\n"); 
-   printf("  vobinfo version 1.0\n"); 
+   printf("  vobinfo version 1.2\n"); 
    printf("  Written by Rick Dean <vobTools@fdd.com>.\n");
    printf("  Copyright (c) 1999 Rick Dean."); 
    printf("  Released under version 2 of the GNU Public License.\n");
@@ -621,13 +624,16 @@ static void PrintHelp(void)
 static void ReadCommandLineParms(int argc,char *argv[])
 {
 
+   strcpy(traceFilename,defaultTraceFilename);
+   if(argc == 1) 
+      PrintHelp();  /* This exits */
    argc--;  /* skip name of program */
    argv++;  /* skip name of program */
    for(;argc;argc--,argv++) {  /* for every arg */
-      if(strncasecmp(*argv,"--bittrace",10) == 0 && ((*argv)[10] == '\0' || (*argv)[0] == '=')) {
+      if(strncasecmp(*argv,"--bittrace",10) == 0 && ((*argv)[10] == '\0' || (*argv)[10] == '=')) {
           traceFlag = 1;
-          if((*argv)[0] == '=') {
-             strncpy(traceFilename,&(*argv)[10],sizeof(traceFilename));
+          if((*argv)[10] == '=') {
+             strncpy(traceFilename,&(*argv)[11],sizeof(traceFilename));
              traceFilename[sizeof(traceFilename)-1] = '\0';
           };
       } else if(strcasecmp(*argv,"--nocommentary") == 0) {
@@ -635,12 +641,18 @@ static void ReadCommandLineParms(int argc,char *argv[])
       } else if(strcasecmp(*argv,"--nosummary") == 0) {
           summaryFlag=0;
       } else if(strcasecmp(*argv,"--tracepayload") == 0) {
+          traceFlag=1;
           tracePayload=1;
       } else if(strcasecmp(*argv,"--traceerrors") == 0) {
+          traceFlag=1;
           traceErrors=1;
       } else if(strcasecmp(*argv,"--demuxall") == 0) {
           demuxAllFlag=1;
       } else if(strncasecmp(*argv,"--demuxid=",10) == 0) {
+          if(demuxOneId) {
+             fprintf(stderr,"only one --demuxid is permitted.\n");
+             exit(-1);
+          };
           if(strncasecmp(*argv,"--demuxid=0x",12) == 0)   /* if hex number specified */
              sscanf(*argv+12,"%x",&demuxOneId);
           else
@@ -655,7 +667,7 @@ static void ReadCommandLineParms(int argc,char *argv[])
           strncpy(demuxOneFilename,&(*argv)[16],sizeof(demuxOneFilename));
           demuxOneFilename[sizeof(demuxOneFilename)-1] = '\0';
       } else if(strcasecmp(*argv,"--help-stream_id") == 0) {
-          PrintHelpStreamId();
+          PrintHelpStreamId();  /* This exits */
       } else if(strncasecmp(*argv,"--vob=",6) == 0) {
           strncpy(vobFilename,&(*argv)[6],sizeof(vobFilename));
           vobFilename[sizeof(vobFilename)-1] = '\0';
@@ -664,10 +676,12 @@ static void ReadCommandLineParms(int argc,char *argv[])
           demuxPath[sizeof(demuxPath)-1] = '\0';
       } else {
           printf("problem with command arg \"%s\"\n",*argv);
-          PrintHelp();
+          PrintHelp();  /* This exits */
       };
    };
-   if(strcmp(demuxOneFilename,"-") == 0) /* if we are demux'ing one to standard out */
+   if(strcmp(traceFilename,"-") == 0) /* if we are tracing to standard out */
+      commentaryFlag = summaryFlag = 0;
+   if(strcmp(demuxOneFilename,"-") == 0 && demuxOneId) /* if we are demux'ing one to standard out */
       commentaryFlag = summaryFlag = 0;
 }
 
